==> xmedcon-0.8.2.tbz: include/xmedcon/m-getopt.h <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * filename: m-getopt.h                                                    *
 *                                                                         *
 * UTIL C-source: Medical Image Conversion Utility                         *
 *                                                                         *
 * purpose      : m-getopt.c header file                                   *
 *                                                                         *
 * project      : (X)MedCon by Erik Nolf                                   *
 *                                                                         *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* $Id: m-getopt.h,v 1.4 2001/12/26 19:15:04 enlf Exp $
 */

/*
   Copyright (C) 1997-2002 by Erik Nolf

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any later
   version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
   Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   59 Place - Suite 330, Boston, MA 02111-1307, USA.  */

#ifndef __M_GETOPT_H__
#define __M_GETOPT_H__

/****************************************************************************
                              D E F I N E S 
****************************************************************************/

/* global arrays for argument handling */
extern char *mdc_arg_files[];    /* array of pointers to input filenames    */
extern int   mdc_arg_convs[];    /* counter for each conversion format      */
extern int   mdc_arg_total[];    /* totals arguments for files & conversion */


/****************************************************************************
                            F U N C T I O N S
****************************************************************************/

void MdcPrintGlobalOptions(void);
void MdcPrintLocalOptions(void);
void MdcPrintShortInfo(void);
void MdcPrintUsage(char *pgrname);
int  MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES);

#endif

==> xmedcon-0.9.7.1.tbz: include/xmedcon/m-getopt.h <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * filename: m-getopt.h                                                    *
 *                                                                         *
 * UTIL C-source: Medical Image Conversion Utility                         *
 *                                                                         *
 * purpose      : m-getopt.c header file                                   *
 *                                                                         *
 * project      : (X)MedCon by Erik Nolf                                   *
 *                                                                         *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* $Id: m-getopt.h,v 1.7 2004/01/04 22:36:16 enlf Exp $
 */

/*
   Copyright (C) 1997-2004 by Erik Nolf

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any later
   version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
   Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   59 Place - Suite 330, Boston, MA 02111-1307, USA.  */

#ifndef __M_GETOPT_H__
#define __M_GETOPT_H__

/****************************************************************************
                              D E F I N E S 
****************************************************************************/

/* global arrays for argument handling */
extern char *mdc_arg_files[MDC_MAX_FILES]; /* array of pointers to filenames */
extern int   mdc_arg_convs[MDC_MAX_FRMTS]; /* counter each conversion format */
extern int   mdc_arg_total[2];    /* totals arguments for files & conversion  */


/****************************************************************************
                            F U N C T I O N S
****************************************************************************/

void MdcPrintGlobalOptions(void);
void MdcPrintLocalOptions(void);
void MdcPrintShortInfo(void);
void MdcPrintUsage(char *pgrname);
int  MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES);

#endif
